// AWS AUTH config map
resource "kubernetes_config_map" "aws_auth" {
  depends_on = [
    aws_eks_cluster.cluster,
    aws_security_group.cluster,
    null_resource.wait_for_cluster
  ]

  metadata {
    name      = "aws-auth"
    namespace = "kube-system"
    labels = merge(
      {
        "app.kubernetes.io/managed-by" = "Terraform"
      },
      var.aws_auth_additional_labels
    )
  }

  data = {
    mapRoles = yamlencode(
      distinct(concat(
        [{
          rolearn  = aws_iam_role.node.arn
          username = "system:node:{{EC2PrivateDNSName}}",
          groups = [
            "system:bootstrappers",
            "system:nodes"
          ]
        }],
        var.map_roles,
      ))
    )
    mapUsers    = yamlencode(var.map_users)
    mapAccounts = yamlencode(var.map_accounts)
  }
}
