variable "cluster_name" {
  description = "The name of the EKS cluster"
  type        = string
}

variable "node_pools" {
  description = "List of node pools settings to be created. Each item in the list is the additional node pool"
  # Accepted object in the list
  # {
  #   name               = string,
  #   instance_type      = string,
  #   instance_disk_size = number,
  #   instance_count_min = number,
  #   instance_count_max = number,
  # }
  type    = any
  default = []
}

variable "k8s_version" {
  description = "Kubernetes version to deploy"
  type        = string
}

variable "logging" {
  description = "Which types of the control plane logging to be enabled on the cluster, see: https://docs.aws.amazon.com/eks/latest/userguide/control-plane-logs.html"
  type        = list(string)
  default     = []
}

variable "logging_retention_in_days" {
  description = "Number of days to keep the logs in the Cloudwatch. Possible values are 1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1827, 3653, and 0 (to keep the logs forever)"
  type        = number
  default     = 7
}

variable "vpc_id" {
  description = "The VPC is to use for the cluster"
  type        = string
}

variable "cluster_subnet_ids" {
  description = "The list of subnets to use for the cluster"
  type        = list(string)
}

variable "nodes_subnet_ids" {
  description = "The list of subnets to use for nodes"
  type        = list(string)
}

variable "aws_auth_additional_labels" {
  description = "The lables which must be added to aws-auth configmap"
  type        = map(string)
  default     = {}
}

variable "map_roles" {
  description = "Additional IAM roles to add to the aws-auth configmap"
  type = list(object({
    rolearn  = string
    username = string
    groups   = list(string)
  }))
  default = []
}

variable "map_users" {
  description = "Additional IAM users to add to the aws-auth configmap"
  type = list(object({
    userarn  = string
    username = string
    groups   = list(string)
  }))
  default = []
}

variable "map_accounts" {
  description = "Additional AWS account numbers to add to the aws-auth configmap"
  type        = list(string)
  default     = []
}
